# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/nixtlats/',
                'doc_host': 'https://Nixtla.github.io',
                'git_url': 'https://github.com/Nixtla/nixtla/',
                'lib_path': 'nixtlats'},
  'syms': { 'nixtlats.client': {},
            'nixtlats.core.api_error': {},
            'nixtlats.core.client_wrapper': {},
            'nixtlats.core.datetime_utils': {},
            'nixtlats.core.jsonable_encoder': {},
            'nixtlats.core.remove_none_from_dict': {},
            'nixtlats.date_features': { 'nixtlats.date_features.CountryHolidays': ( 'date_features.html#countryholidays',
                                                                                    'nixtlats/date_features.py'),
                                        'nixtlats.date_features.CountryHolidays.__call__': ( 'date_features.html#countryholidays.__call__',
                                                                                             'nixtlats/date_features.py'),
                                        'nixtlats.date_features.CountryHolidays.__init__': ( 'date_features.html#countryholidays.__init__',
                                                                                             'nixtlats/date_features.py'),
                                        'nixtlats.date_features.CountryHolidays.__name__': ( 'date_features.html#countryholidays.__name__',
                                                                                             'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates': ( 'date_features.html#specialdates',
                                                                                 'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates.__call__': ( 'date_features.html#specialdates.__call__',
                                                                                          'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates.__init__': ( 'date_features.html#specialdates.__init__',
                                                                                          'nixtlats/date_features.py'),
                                        'nixtlats.date_features.SpecialDates.__name__': ( 'date_features.html#specialdates.__name__',
                                                                                          'nixtlats/date_features.py'),
                                        'nixtlats.date_features._get_holidays_df': ( 'date_features.html#_get_holidays_df',
                                                                                     'nixtlats/date_features.py'),
                                        'nixtlats.date_features._transform_dict_holidays': ( 'date_features.html#_transform_dict_holidays',
                                                                                             'nixtlats/date_features.py')},
            'nixtlats.distributed.timegpt': { 'nixtlats.distributed.timegpt._DistributedTimeGPT': ( 'distributed.timegpt.html#_distributedtimegpt',
                                                                                                    'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.__init__': ( 'distributed.timegpt.html#_distributedtimegpt.__init__',
                                                                                                             'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._cross_validation': ( 'distributed.timegpt.html#_distributedtimegpt._cross_validation',
                                                                                                                      'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._detect_anomalies': ( 'distributed.timegpt.html#_distributedtimegpt._detect_anomalies',
                                                                                                                      'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._distribute_method': ( 'distributed.timegpt.html#_distributedtimegpt._distribute_method',
                                                                                                                       'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._forecast': ( 'distributed.timegpt.html#_distributedtimegpt._forecast',
                                                                                                              'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._forecast_x': ( 'distributed.timegpt.html#_distributedtimegpt._forecast_x',
                                                                                                                'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._get_anomalies_schema': ( 'distributed.timegpt.html#_distributedtimegpt._get_anomalies_schema',
                                                                                                                          'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._get_forecast_schema': ( 'distributed.timegpt.html#_distributedtimegpt._get_forecast_schema',
                                                                                                                         'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT._instantiate_timegpt': ( 'distributed.timegpt.html#_distributedtimegpt._instantiate_timegpt',
                                                                                                                         'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.cross_validation': ( 'distributed.timegpt.html#_distributedtimegpt.cross_validation',
                                                                                                                     'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.detect_anomalies': ( 'distributed.timegpt.html#_distributedtimegpt.detect_anomalies',
                                                                                                                     'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._DistributedTimeGPT.forecast': ( 'distributed.timegpt.html#_distributedtimegpt.forecast',
                                                                                                             'nixtlats/distributed/timegpt.py'),
                                              'nixtlats.distributed.timegpt._cotransform': ( 'distributed.timegpt.html#_cotransform',
                                                                                             'nixtlats/distributed/timegpt.py')},
            'nixtlats.errors.unprocessable_entity_error': {},
            'nixtlats.timegpt': { 'nixtlats.timegpt.TimeGPT': ('timegpt.html#timegpt', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT._instantiate_distributed_timegpt': ( 'timegpt.html#timegpt._instantiate_distributed_timegpt',
                                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT.cross_validation': ( 'timegpt.html#timegpt.cross_validation',
                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT.detect_anomalies': ( 'timegpt.html#timegpt.detect_anomalies',
                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.TimeGPT.forecast': ('timegpt.html#timegpt.forecast', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT': ('timegpt.html#_timegpt', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT.__init__': ('timegpt.html#_timegpt.__init__', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT._cross_validation': ( 'timegpt.html#_timegpt._cross_validation',
                                                                                   'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT._detect_anomalies': ( 'timegpt.html#_timegpt._detect_anomalies',
                                                                                   'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT._forecast': ('timegpt.html#_timegpt._forecast', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT.plot': ('timegpt.html#_timegpt.plot', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPT.validate_token': ( 'timegpt.html#_timegpt.validate_token',
                                                                                'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel': ('timegpt.html#_timegptmodel', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.__init__': ('timegpt.html#_timegptmodel.__init__', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel._call_api': ( 'timegpt.html#_timegptmodel._call_api',
                                                                                'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel._retry_strategy': ( 'timegpt.html#_timegptmodel._retry_strategy',
                                                                                      'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.add_date_features': ( 'timegpt.html#_timegptmodel.add_date_features',
                                                                                        'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.compute_date_feature': ( 'timegpt.html#_timegptmodel.compute_date_feature',
                                                                                           'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.cross_validation': ( 'timegpt.html#_timegptmodel.cross_validation',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.dataframes_to_dict': ( 'timegpt.html#_timegptmodel.dataframes_to_dict',
                                                                                         'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.detect_anomalies': ( 'timegpt.html#_timegptmodel.detect_anomalies',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.forecast': ('timegpt.html#_timegptmodel.forecast', 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.infer_freq': ( 'timegpt.html#_timegptmodel.infer_freq',
                                                                                 'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.make_future_dataframe': ( 'timegpt.html#_timegptmodel.make_future_dataframe',
                                                                                            'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.preprocess_X_df': ( 'timegpt.html#_timegptmodel.preprocess_x_df',
                                                                                      'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.preprocess_dataframes': ( 'timegpt.html#_timegptmodel.preprocess_dataframes',
                                                                                            'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.resample_dataframe': ( 'timegpt.html#_timegptmodel.resample_dataframe',
                                                                                         'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.set_model_params': ( 'timegpt.html#_timegptmodel.set_model_params',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.transform_inputs': ( 'timegpt.html#_timegptmodel.transform_inputs',
                                                                                       'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.transform_outputs': ( 'timegpt.html#_timegptmodel.transform_outputs',
                                                                                        'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt._TimeGPTModel.validate_input_size': ( 'timegpt.html#_timegptmodel.validate_input_size',
                                                                                          'nixtlats/timegpt.py'),
                                  'nixtlats.timegpt.validate_model_parameter': ( 'timegpt.html#validate_model_parameter',
                                                                                 'nixtlats/timegpt.py')},
            'nixtlats.types.http_validation_error': {},
            'nixtlats.types.multi_series_input': {},
            'nixtlats.types.single_series_forecast': {},
            'nixtlats.types.validation_error': {},
            'nixtlats.types.validation_error_loc_item': {},
            'nixtlats.utils': {'nixtlats.utils.colab_badge': ('utils.html#colab_badge', 'nixtlats/utils.py')}}}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime


class SingleSeriesForecast(pydantic.BaseModel):
    model: typing.Optional[str] = pydantic.Field(
        description="Model to use as a string. Options are: `timegpt-1`, and `timegpt-1-long-horizon.` We recommend using `timegpt-1-long-horizon` for forecasting if you want to predict more than one seasonal period given the frequency of your data."
    )
    freq: typing.Optional[str] = pydantic.Field(
        description="The frequency of the data represented as a string. 'D' for daily, 'M' for monthly, 'H' for hourly, and 'W' for weekly frequencies are available."
    )
    level: typing.Optional[typing.List[typing.Any]] = pydantic.Field(
        description="A list of values representing the prediction intervals. Each value is a percentage that indicates the level of certainty for the corresponding prediction interval. For example, [80, 90] defines 80% and 90% prediction intervals."
    )
    fh: typing.Optional[int] = pydantic.Field(
        description="The forecasting horizon. This represents the number of time steps into the future that the forecast should predict."
    )
    y: typing.Optional[typing.Any]
    x: typing.Optional[typing.Dict[str, typing.List[float]]] = pydantic.Field(
        description='The exogenous variables provided as a dictionary. Each key is a timestamp (string format: YYYY-MM-DD) and the corresponding value is a list of exogenous variable values at that time point. For example: {"2021-01-01": [0.1], "2021-01-02": [0.4]}. This should also include forecasting horizon (fh) additional timestamps to calculate the future values.'
    )
    clean_ex_first: typing.Optional[bool] = pydantic.Field(
        description="A boolean flag that indicates whether the API should preprocess (clean) the exogenous signal before applying the large time model. If True, the exogenous signal is cleaned; if False, the exogenous variables are applied after the large time model."
    )
    finetune_steps: typing.Optional[int] = pydantic.Field(
        description="The number of tuning steps used to train the large time model on the data. Set this value to 0 for zero-shot inference, i.e., to make predictions without any further model tuning."
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/utils.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/utils.ipynb 3
def colab_badge(path: str):
    from IPython.display import Markdown

    base_url = "https://colab.research.google.com/github"
    badge_svg = "https://colab.research.google.com/assets/colab-badge.svg"
    nb_url = f"{base_url}/Nixtla/nixtla/blob/main/nbs/{path}.ipynb"
    badge_md = f"[![]({badge_svg})]({nb_url})"
    display(Markdown(badge_md))



import os
import re

import fire
from dotenv import load_dotenv

load_dotenv()


def create_sdk_reference(
    save_dir,
    slug_number,
    host_url=os.environ["README_HOST_URL"],
    category=os.environ["README_CATEGORY"],
):
    file_path = f"{save_dir}/{slug_number}_sdk_reference.md"
    header = f"""---
title: "SDK Reference"
slug: "sdk_reference"
order: {slug_number}
type: "link"
link_url: "https://nixtla.github.io/nixtla/timegpt.html"
link_external: true
category: {category}
---

    """

    with open(file_path, "w", encoding="utf-8") as file:
        file.write(header)


if __name__ == "__main__":
    fire.Fire(create_sdk_reference)



# This file was auto-generated by Fern from our API Definition.

from .http_validation_error import HttpValidationError
from .multi_series_input import MultiSeriesInput
from .single_series_forecast import SingleSeriesForecast
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem

__all__ = [
    "HttpValidationError",
    "MultiSeriesInput",
    "SingleSeriesForecast",
    "ValidationError",
    "ValidationErrorLocItem",
]



import setuptools

with open("README.md", "r", encoding="utf8") as fh:
    long_description = fh.read()

dev = ["black", "nbdev", "plotly", "python-dotenv", "statsforecast"]
distributed = ["dask", "fugue[ray]", "pyspark"]
plotting = ["utilsforecast[plotting]>=0.0.5"]
date_extras = ["holidays"]

setuptools.setup(
    name="nixtlats",
    version="0.1.18",
    description="TimeGPT SDK",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Nixtla/nixtla",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    install_requires=[
        "httpx",
        "pandas",
        "pydantic<2",
        "requests",
        "tenacity",
        "utilsforecast>=0.0.13",
    ],
    extras_require={
        "dev": dev + distributed + plotting + date_extras,
        "distributed": distributed,
        "plotting": plotting,
        "date_extras": date_extras,
    },
)



import os
import re

import fire
from dotenv import load_dotenv

load_dotenv()


def to_snake_case(s):
    s = s.lower()
    s = re.sub(r"(?<!^)(?=[A-Z])", "_", s).lower()
    s = re.sub(r"\W", "_", s)
    s = re.sub(r"_+", "_", s)
    return s


def merge_lines(md_text):
    code_block_pattern = re.compile(r"``` (?:python|bash)([\s\S]*?)```", re.MULTILINE)
    code_blocks = code_block_pattern.findall(md_text)
    md_text_no_code = code_block_pattern.sub("CODEBLOCK", md_text)
    lines = md_text_no_code.split("\n")
    merged_lines = []
    buffer_line = ""
    in_div_block = False
    for line in lines:
        if line.strip().lower().startswith("<div>"):
            in_div_block = True
        elif line.strip().lower().endswith("</div>"):
            in_div_block = False
        if in_div_block or line.startswith(
            ("    ", "> ", "#", "-", "*", "1.", "2.", "3.", "CODEBLOCK", "!", "[")
        ):
            if buffer_line:
                merged_lines.append(buffer_line.strip())
                buffer_line = ""
            merged_lines.append(line)
        else:
            buffer_line += line.strip() + " "
    if buffer_line:
        merged_lines.append(buffer_line.strip())
    md_text_merged = "\n".join(merged_lines)
    for code_block in code_blocks:
        md_text_merged = md_text_merged.replace(
            "CODEBLOCK", f"\n``` python\n{code_block}\n```\n", 1
        )
    return md_text_merged


def modify_markdown(
    file_path,
    slug_number=0,
    host_url=os.environ["README_HOST_URL"],
    category=os.environ["README_CATEGORY"],
):
    with open(file_path, "r", encoding="utf-8") as file:
        content = file.read()
    dir_path = os.path.dirname(file_path)
    if not dir_path.endswith("/"):
        dir_path += "/"

    # Extract and remove the first markdown header
    pattern_header = re.compile(r"^#\s+(.*)\n+", re.MULTILINE)
    match = pattern_header.search(content)

    if match:
        title = match.group(1)
        content = pattern_header.sub("", content, count=1)  # remove the first match
    else:
        title = "Something Amazing"
    slug = to_snake_case(title)

    # Prepare the new header
    header = f"""---
title: "{title}"
slug: "{slug}"
order: {slug_number}
category: {category}
hidden: false
---

    """

    # Remove parts delimited by ::: :::
    pattern_delimited = re.compile(r":::.*?:::", re.DOTALL)
    content = pattern_delimited.sub("", content)

    # Modify image paths
    content = content.replace("![figure](../../", f"![figure]({host_url}/nbs/")
    pattern_image = re.compile(r"!\[\]\(((?!.*\.svg).*?)\)")
    modified_content = pattern_image.sub(
        r"![](" + host_url + dir_path + r"\1)", content
    )

    # Concatenate new header and modified content
    final_content = header + merge_lines(modified_content)

    with open(file_path, "w", encoding="utf-8") as file:
        file.write(final_content)


if __name__ == "__main__":
    fire.Fire(modify_markdown)
